@@ -14,24 +14,24 @@
     tool = ifelse(is.null(swftools), paste(dev, "2swf", sep = ""), 
         shQuote(file.path(swftools, paste(dev, "2swf", sep = ""))))
     if (.Platform$OS.type == "windows") 
-        system <- shell
-    version <- system(tool, intern = TRUE)
+        system = shell
+    version = system(tool, intern = TRUE)
     if (length(version) < 10) 
         stop("swftools not found; please install swftools first: http://www.swftools.org")
-    wildcard <- paste(filename, "*.", dev, sep = "")
-    convert <- paste(tool, wildcard, "-o", swfname)
+    wildcard = paste(filename, "*.", dev, sep = "")
+    convert = paste(tool, wildcard, "-o", swfname)
     cmd = -1
     if (dev == "png" | dev == "jpeg") {
         convert = paste(convert, "-r", 1/interval)
-        cat("Executing: ", convert, "\n")
+        message("Executing: ", convert)
         cmd = system(convert)
     }
     else {
         convert = paste(convert, " -s framerate=", 1/interval, sep = "")
-        cat("Executing: ", convert, "\n")
+        message("Executing: ", convert)
         cmd = system(convert)
     }
-    if (cmd == 0) cat("Flash has been created at: ", normalizePath(file.path(outdir, 
-        swfname)), "\n")
+    if (cmd == 0) message("Flash has been created at: ", normalizePath(file.path(outdir,
+        swfname)))
     invisible(cmd)
 } 
